@@ -32,7 +32,8 @@ char *file_dirname(const char *filename);
 int fd_length(int fd);
 int file_mode(const char *filename);
 FILE *file_open_mode(const char *filename, const char *rw, mode_t mode);
-char *file_make_absolute_to(const char *filename, const char *absfile);
+char *file_make_absolute_to_file(const char *filename, const char *absfile);
+char *file_make_absolute_to_dir(const char *filename, const char *absdir);
 char *file_make_absolute(const char *filename);
 int file_exists(const char *filename);
 int file_is_regular(const char *filename);
