@@ -22,8 +22,9 @@
 #include "estring.H"
 #include "string_var.H"
 #include "tok.H"
+#include "confsection.H"
 
-CVSID("$Id: ui.c,v 1.32 2006/06/27 13:31:13 gnb Exp $");
+CVSID("$Id: ui.c,v 1.37 2010/01/08 08:51:08 gnb Exp $");
 
 /*-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
 
@@ -111,7 +112,7 @@ find_file(const char *path, const char *base)
     
     while ((dir = tok.next()) != 0)
     {
-	file = g_strconcat(dir, "/", base, 0);
+	file = g_strconcat(dir, "/", base, (char *)0);
 
 	if (stat(file, &sb) == 0 && S_ISREG(sb.st_mode))
 	    return file.take();
@@ -123,12 +124,12 @@ find_file(const char *path, const char *base)
 void
 ui_prepend_glade_path(const char *dir)
 {
-    ui_glade_path = g_strconcat(dir, ":", ui_glade_path.data(), 0);
+    ui_glade_path = g_strconcat(dir, ":", ui_glade_path.data(), (char *)0);
 }
 
 /*-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
 
-extern struct { const char *name; GCallback func; } ui_callbacks[];   /* in glade_callbacks.c */
+extern ui_named_callback_t ui_callbacks[];   /* in glade_callbacks.c */
 
 /*
  * Connect up named functions for signal handlers.
@@ -259,7 +260,7 @@ ui_get_window(GtkWidget *w)
 
 static struct
 {
-    char **xpm;
+    const char * const *xpm;
     GdkPixmap *pm;
     GdkBitmap *mask;
 } ui_default_icon;
@@ -288,13 +289,13 @@ ui_window_set_default_icon(GtkWidget *w)
     if (ui_default_icon.pm == 0)
     	ui_default_icon.pm = gdk_pixmap_create_from_xpm_d(w->window,
 	    	    	    	&ui_default_icon.mask, 0,
-				ui_default_icon.xpm);
+				(char **)ui_default_icon.xpm);
     gdk_window_set_icon(w->window, 0,
 	ui_default_icon.pm, ui_default_icon.mask);
 }
 
 void
-ui_set_default_icon(char **xpm_data)
+ui_set_default_icon(const char * const *xpm_data)
 {
     ui_default_icon.xpm = xpm_data;
     ui_default_icon.pm = 0; 	/* JIC */
@@ -729,6 +730,7 @@ ui_list_set_column_visibility(GtkWidget *w, int col, gboolean vis)
 
 #if GTK2
 static PangoFontDescription *ui_text_font_desc;
+static gboolean ui_text_font_dirty = FALSE;
 #else
 /* we have to fake a *lot* of stuff for gtk1.2 */
 static GdkFont *ui_text_font;
@@ -777,6 +779,11 @@ ui_text_line_start(GtkText *text, ui_text_data *td)
 
 #endif /* !GTK2 */
 
+#if GTK2
+#define UI_TEXT_SCALE_FACTOR	1.1
+#define UI_TEXT_DEFAULT_SIZE	10240
+#endif
+
 void
 ui_text_setup(GtkWidget *w)
 {
@@ -787,14 +794,25 @@ ui_text_setup(GtkWidget *w)
      * Override the font in the text window: it needs to be
      * fixedwidth so the source aligns properly.
      */
+    if (ui_text_font_dirty)
+    {
+	/* User changed text size */
+	g_assert(ui_text_font_desc != 0);
+	pango_font_description_free(ui_text_font_desc);
+	ui_text_font_desc = 0;
+	ui_text_font_dirty = FALSE;
+    }
     if (ui_text_font_desc == 0)
+    {
     	ui_text_font_desc = pango_font_description_from_string("monospace");
+	confsection_t *cs = confsection_t::get("general");
+	gint size = cs->get_int("text_size", UI_TEXT_DEFAULT_SIZE);
+	pango_font_description_set_size(ui_text_font_desc, size);
+    }
     gtk_widget_modify_font(w, ui_text_font_desc);
 
-#ifndef HAVE_GTK_TEXT_BUFFER_SELECT_RANGE
-    /* hacky select_region() implementation relies on not having line wrapping */
+    /* Suppress wrap: it screws up our pretence of being multi-column */
     gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(w), GTK_WRAP_NONE);
-#endif /* !HAVE_GTK_TEXT_BUFFER_SELECT_RANGE */
 
 #else /* !GTK2 */
     ui_text_data *td;
@@ -821,12 +839,12 @@ int
 ui_text_font_width(GtkWidget *w)
 {
 #if GTK2
-    /*
-     * Yes this is a deprecated function...but there doesn't
-     * seem to be any other way to get a font width.
-     */
-    GdkFont *font = gtk_style_get_font(gtk_widget_get_style(w));
-    return uix_font_width(font);
+    PangoLayout *layout = gtk_widget_create_pango_layout(w, "W");
+    PangoRectangle ink, logical;
+    pango_layout_get_pixel_extents(layout, &ink, &logical);
+    g_object_unref(layout);
+    return logical.width;
+
 #else /* !GTK2 */
     return uix_font_width(ui_text_font);
 #endif /* !GTK2 */
@@ -834,6 +852,43 @@ ui_text_font_width(GtkWidget *w)
 
 /*-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
 
+void
+ui_text_adjust_text_size(GtkWidget *w, int dirn)
+{
+#if GTK2
+    static const char normal_size_key[] = "ui-text-normal-size";
+
+    PangoFontDescription *font_desc = w->style->font_desc;
+    gint size = pango_font_description_get_size(font_desc);
+
+    gint normal_size = GPOINTER_TO_INT(gtk_object_get_data(GTK_OBJECT(w),
+							    normal_size_key));
+    if (normal_size == 0)
+    {
+	normal_size = pango_font_description_get_size(ui_text_font_desc);
+	gtk_object_set_data(GTK_OBJECT(w), normal_size_key,
+			    GINT_TO_POINTER(normal_size));
+    }
+
+    if (dirn < 0)
+	size = (gint)((double)size / UI_TEXT_SCALE_FACTOR + 0.5);
+    else if (dirn == 0)
+	size = normal_size;
+    else
+	size = (gint)((double)size * UI_TEXT_SCALE_FACTOR + 0.5);
+
+    font_desc = pango_font_description_copy(font_desc);
+    pango_font_description_set_size(font_desc, size);
+    gtk_widget_modify_font(w, font_desc);
+
+    confsection_t::get("general")->set_int("text_size", size);
+    confsection_t::sync();
+    ui_text_font_dirty = TRUE;
+#endif
+}
+
+/*-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
+
 ui_text_tag *
 ui_text_create_tag(GtkWidget *w, const char *name, GdkColor *fg)
 {
